==> mysql1-0.16.1.tar.gz: test/unit/binary_data_packet_test.dart <==
library mysql1.binary_data_packet_test;

import 'package:mysql1/mysql1.dart';
import 'package:mysql1/constants.dart';
import 'package:mysql1/src/buffer.dart';
import 'package:mysql1/src/prepared_statements/binary_data_packet.dart';
import 'package:mysql1/src/results/field_impl.dart';

import 'package:test/test.dart';

void main() {
  group('buffer:', () {
    test('can read short blob', () {
      var packet = new BinaryDataPacket.forTests(null, null);
      var field = new FieldImpl.forTests(FIELD_TYPE_BLOB);
      var buffer = new Buffer.fromList([1, 32]);
      var value = packet.readField(field, buffer);

      expect(value, new isInstanceOf<Blob>());
      expect((value as Blob).toString(), equals(" "));
    });

    test('can read long blob', () {
      var packet = new BinaryDataPacket.forTests(null, null);
      var field = new FieldImpl.forTests(FIELD_TYPE_BLOB);

      var buffer = new Buffer(500 + 3);
      buffer.writeLengthCodedBinary(500);
      for (int i = 0; i < 500; i++) {
        buffer.writeByte(32);
      }
      var value = packet.readField(field, buffer);

      expect(value, new isInstanceOf<Blob>());
      expect((value as Blob).toString(), hasLength(500));
    });

    test('can read very long blob', () {
      var packet = new BinaryDataPacket.forTests(null, null);
      var field = new FieldImpl.forTests(FIELD_TYPE_BLOB);

      var buffer = new Buffer(50000 + 3);
      buffer.writeLengthCodedBinary(50000);
      for (int i = 0; i < 50000; i++) {
        buffer.writeByte(32);
      }
      var value = packet.readField(field, buffer);

      expect(value, new isInstanceOf<Blob>());
      expect((value as Blob).toString(), hasLength(50000));
    });
  });
}

==> mysql1-0.16.2.tar.gz: test/unit/binary_data_packet_test.dart <==
library mysql1.binary_data_packet_test;

import 'package:mysql1/mysql1.dart';
import 'package:mysql1/src/buffer.dart';
import 'package:mysql1/src/constants.dart';
import 'package:mysql1/src/prepared_statements/binary_data_packet.dart';
import 'package:mysql1/src/results/field.dart';

import 'package:test/test.dart';

void main() {
  group('buffer:', () {
    test('can read short blob', () {
      var packet = new BinaryDataPacket.forTests(null, null);
      var field = new Field.forTests(FIELD_TYPE_BLOB);
      var buffer = new Buffer.fromList([1, 32]);
      var value = packet.readField(field, buffer);

      expect(value, new isInstanceOf<Blob>());
      expect((value as Blob).toString(), equals(" "));
    });

    test('can read long blob', () {
      var packet = new BinaryDataPacket.forTests(null, null);
      var field = new Field.forTests(FIELD_TYPE_BLOB);

      var buffer = new Buffer(500 + 3);
      buffer.writeLengthCodedBinary(500);
      for (int i = 0; i < 500; i++) {
        buffer.writeByte(32);
      }
      var value = packet.readField(field, buffer);

      expect(value, new isInstanceOf<Blob>());
      expect((value as Blob).toString(), hasLength(500));
    });

    test('can read very long blob', () {
      var packet = new BinaryDataPacket.forTests(null, null);
      var field = new Field.forTests(FIELD_TYPE_BLOB);

      var buffer = new Buffer(50000 + 3);
      buffer.writeLengthCodedBinary(50000);
      for (int i = 0; i < 50000; i++) {
        buffer.writeByte(32);
      }
      var value = packet.readField(field, buffer);

      expect(value, new isInstanceOf<Blob>());
      expect((value as Blob).toString(), hasLength(50000));
    });
  });
}
